.. image:: https://travis-ci.org/ambitioninc/django-restraint.png
   :target: https://travis-ci.org/ambitioninc/django-restraint

.. image:: https://coveralls.io/repos/ambitioninc/django-restraint/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/django-restraint?branch=develop

.. image:: https://pypip.in/v/django-restraint/badge.png
    :target: https://pypi.python.org/pypi/django-restraint/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/django-restraint/badge.png
    :target: https://pypi.python.org/pypi/django-restraint/
    :alt: Number of PyPI downloads


django-restraint
===============

Restraint is a dynamic object-level permission system for Django.

Installation
------------
To install the latest release, type::

    pip install django-restraint

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-restraint.git

Documentation
=============

Full documentation is available at http://django-restraint.readthedocs.org

License
=======
MIT License (see LICENSE)